==> commons-logging-3.1.0-sources.jar: org/seppiko/commons/logging/LoggingBuilder.java <==
/*
 * Copyright 2022 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.seppiko.commons.logging;

import java.util.function.Supplier;

/**
 * Logging builder interface
 *
 * @author Leonard Woo
 */
public interface LoggingBuilder {

  /**
   * Set message
   *
   * @param message the message object to log.
   * @return a LoggingBuilder, usually <b>this</b>.
   */
  LoggingBuilder message(CharSequence message);

  /**
   * Set throwable
   *
   * @param cause the Throwable to log, including its stack trace.
   * @return a LoggingBuilder, usually <b>this</b>.
   */
  LoggingBuilder withCause(Throwable cause);

  /**
   * Set object parameter
   *
   * @param paramSupplier the parameters to log.
   * @return a LoggingBuilder, usually <b>this</b>.
   */
  LoggingBuilder param(Supplier<?> paramSupplier);

  /**
   * Set object parameter
   *
   * @param paramObject the parameters to log.
   * @return a LoggingBuilder, usually <b>this</b>.
   */
  LoggingBuilder param(Object paramObject);

  /** Log builder. */
  void log();
}

==> commons-logging-3.2.0-sources.jar: org/seppiko/commons/logging/LoggingBuilder.java <==
/*
 * Copyright 2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.seppiko.commons.logging;

import java.util.function.Supplier;

/**
 * Logging builder interface
 *
 * @author Leonard Woo
 */
public interface LoggingBuilder {

  /**
   * Set message.
   *
   * @param message the message object to log.
   * @return a LoggingBuilder, usually <b>this</b>.
   */
  LoggingBuilder message(CharSequence message);

  /**
   * Set throwable.
   *
   * @param cause the Throwable to log, including its stack trace.
   * @return a LoggingBuilder, usually <b>this</b>.
   */
  LoggingBuilder withCause(Throwable cause);

  /**
   * Set object parameter.
   *
   * @param paramSupplier the parameters to log.
   * @return a LoggingBuilder, usually <b>this</b>.
   */
  LoggingBuilder param(Supplier<?> paramSupplier);

  /**
   * Set object parameter.
   *
   * @param paramObject the parameters to log.
   * @return a LoggingBuilder, usually <b>this</b>.
   */
  LoggingBuilder param(Object paramObject);

  /** Log builder. */
  void log();
}
